<?php
/**
 * Plugin Name: Custom Windows Pinned Tiles
 * Plugin URI: http://celloexpressions.com/dev/articles/custom-windows-pinned-tiles/
 * Description: Customize the tiles that Windows 8/IE 10 users can pin to their start screen with your logo and colors.
 * Version: 1.0
 * Author: Nick Halsey
 * Author URI: http://celloexpressions.com/
 * Tags: windows 8, internet explorer, IE 10, tiles, start screen, pinned site, branding, favicon
 * License: GPL

=====================================================================================
Copyright (C) 2013 Nick Halsey

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with WordPress; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
=====================================================================================
*/

// Set-up Action and Filter Hooks
if ( is_admin() ){
	register_activation_hook(__FILE__, 'cwptiles_add_defaults');
	register_uninstall_hook(__FILE__, 'cwptiles_delete_plugin_options');
	add_action('admin_init', 'cwptiles_init' );
	add_action('admin_menu', 'cwptiles_add_options_page');
	add_filter( 'plugin_action_links', 'cwptiles_plugin_action_links', 10, 2 );
}

// Delete options table entries ONLY when plugin deactivated AND deleted
function cwptiles_delete_plugin_options() {
	delete_option('cwptiles_options');
}
// Display a Settings link on the main plugins page
function cwptiles_plugin_action_links( $links, $file ) {
	if ( $file == plugin_basename( __FILE__ ) ) {
		$cwptiles_links = '<a href="'.get_admin_url().'options-general.php?page=custom-windows-pinned-tiles%2Fcustom-windows-pinned-tiles.php">'.__('Settings').'</a>';
		// make the 'Settings' link appear first
		array_unshift( $links, $cwptiles_links );
	}
	return $links;
}

// Define default option settings
function cwptiles_add_defaults() {
	$tmp = get_option('cwptiles_options');
    if(!is_array($tmp)) {
		delete_option('cwptiles_options'); 
		$arr = array(	
						'plugin_version' => '0.0',
						'background-color' => '#111111',
						'imgurl' => plugins_url('/default-wp-logo.png',__FILE__),
						'title' => get_bloginfo('name')
		);
		update_option('cwptiles_options', $arr);
	}
}

// Init plugin options to white list our options
function cwptiles_init(){
	register_setting( 'cwptiles_plugin_options', 'cwptiles_options', 'cwptiles_validate_options' );
}

// Add menu page
function cwptiles_add_options_page(){
	add_options_page('Custom Windows Pinned Tile Settings', 'Windows Pinned Tiles', 'manage_options', __FILE__, 'cwptiles_render_form');
}

// Prepare the media uploader
function cwptiles_admin_scripts(){
	// must be running 3.5+ to use color pickers and image upload
	wp_enqueue_media();
	wp_enqueue_style( 'wp-color-picker' );
	wp_enqueue_script('public-beta-admin', plugins_url("/pinned-tiles-admin.js", __FILE__), array('wp-color-picker', 'jquery'));
}
if (isset($_GET['page']) && $_GET['page'] == 'custom-windows-pinned-tiles/custom-windows-pinned-tiles.php') {
	add_action('init', 'cwptiles_admin_scripts');
}
function cwptiles_render_form(){
	$options = get_option('cwptiles_options');
?>
	<div class="wrap">
	<style type="text/css">
		#tile-preview-container {
			float: right;
			width: 40%;
			min-width: 200px;
			max-width: 410px;
			height: 600px;
			position: relative;
			background: url('<?php echo plugins_url('/start-screen-preview.png',__FILE__); ?>') no-repeat top left;
		}
		.live-preview-tile {
			color: #ffffff;
			width: 118px;
			height: 118px;
			outline: none;
			background-color: <?php echo $options['background-color']; ?>;
			position: absolute;
			overflow: hidden;
			top: 140px;
			left: 93px;
		}
		.live-preview-image {
			position: absolute;
			top: 15px;
			left: 28px;
			width: 64px;
			height: 64px;
		}
		.live-preview-image img {
			max-width: 100%;
			max-height: 100%;
		}
		.live-preview-title {
			max-height: 27px;
			position: absolute;
			bottom: 5px;
			left: 15px;
			width: 90px;
			font-family: "Segoe Light", "Segoe UI", Arial, sans-serif;
			font-size: 12px;
			font-weight: 300;
			letter-spacing: -.02em;
			line-height: 13px;
			color: #ffffff;
			overflow: hidden;
		}
		#preview-disclaimer {
			position: absolute;
			bottom: 20px;
			left: 20px;
			font-size: 14px;
			text-shadow: 1px 1px 1px #000;
			color: #fff;
		}
		table.form-table {
			clear: none;
			float: left;
			width: 60%;
		}
	</style>
	<h2>Custom Windows Pinned Tile Settings</h2><?php // wp messages hook into the page content's first <h2> ?>
	<form method="post" action="options.php" >	
	<?php settings_fields('cwptiles_plugin_options'); ?>
	<div id="tile-preview-container">
		<div class="live-preview-tile" id="preview-tile" title="<?php echo $options['title']; ?>">
			<div class="live-preview-image">
				<img alt="Tile Icon" id="tile-img-preview" src="<?php echo $options['imgurl']; ?>" />
			</div>
			<!-- tile icon -->
			<div class="live-preview-title" id="the_title"><?php echo $options['title']; ?></div>
		</div>
		<div id="preview-disclaimer">Start screen image and preview concept adapted from <a href="http://www.buildmypinnedsite.com/" target="_blank" style="color: #fff">buildmypinnedsite.com</a> (by Microsoft).</div>
    </div>
	<table class="form-table">
		<tr valign="top">
			<th scope="row">Tile Background Color</th>
			<td>
				<input type="text" id="color" class="color-field" name="cwptiles_options[background-color]" value="<?php echo $options['background-color']; ?>" onchange="tilepreview_update()"/>
			</td>
		</tr>
		<tr valign="top">
			<th scope="row">Logo Image<br/><em>Must be PNG format, recommended size 144 x 144px. Image will not be saved if it isn't a .png file.</em></th>
			<td>
				<input type="url" id="imgurl" name="cwptiles_options[imgurl]" value="<?php echo $options['imgurl']; ?>" onchange="tilepreview_update()" />
				<input type="button" class="button" name="img_upload_button" id="img_upload_button" value="Upload/Insert" />
			</td>
		</tr>
		<tr valign="top">
			<th scope="row">Tile Title</th>
			<td>
				<input type="text" id="title" name="cwptiles_options[title]" value="<?php echo $options['title']; ?>" onchange="tilepreview_update()" />
			</td>
		</tr>
	</table>
	<p class="submit">
		<input type="submit" class="button-primary" value="Save Changes" />
	</p>
</form>
</div>
<?php	
} //options page

// Sanitize and validate input. Accepts an array, return a sanitized array.
function cwptiles_validate_options($input) {
	if(substr($input['imgurl'],-3,3) != 'png')
		$input['imgurl'] = '[ERROR: image must be in .png format]';
	elseif(substr($input['imgurl'],0,7) != 'http://' && substr($input['imgurl'],0,8) != 'https://')
		$input['imgurl'] = '[ERROR: image url must begin with http:// or https://]';
	
	return $input;
}
	
// output
function cwptiles_getOption( $option, $options ) {
	if(array_key_exists($option, $options))
		return $options[$option];
	else
		return false;
}
add_action('wp_head', 'cwptiles_output');
function cwptiles_output() {
	$options = get_option('cwptiles_options');
	?>
	<!-- For pinned tiles in Windows start screen: -->
	<meta name="application-name" content="<?php echo cwptiles_getOption('title',$options); ?>" /> 
	<meta name="msapplication-TileColor" content="<?php echo cwptiles_getOption('background-color',$options); ?>" /> 
	<meta name="msapplication-TileImage" content="<?php echo cwptiles_getOption('imgurl',$options); ?>"/>
<?php
}